@@ -2,13 +2,14 @@
 import math
 import time
 import glob
+import numpy as np
 import shapely
 import pandas as pd
 import geopandas as gpd
 from tqdm import tqdm
 import PySimpleGUI as sg
 from shapely.geometry import Polygon
-from shapely.ops import cascaded_union, unary_union
+from shapely.ops import cascaded_union, unary_union, nearest_points
 pd.options.mode.chained_assignment = None
 
 class check_topology:
